0.9.9 API documentation: matrix_common.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

matrix_common.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 #include "../detail/qualifier.hpp"
16 #include "../detail/_fixes.hpp"
17
18 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
19 # pragma message("GLM: GLM_EXT_matrix_transform extension included")
20 #endif
21
22 namespace glm
23 {
26
27 template<length_t C, length_t R, typename T, typename U, qualifier Q>
28 GLM_FUNC_DECL mat<C, R, T, Q> mix(mat<C, R, T, Q> const& x, mat<C, R, T, Q> const& y, mat<C, R, U, Q> const& a);
29
30 template<length_t C, length_t R, typename T, typename U, qualifier Q>
31 GLM_FUNC_DECL mat<C, R, T, Q> mix(mat<C, R, T, Q> const& x, mat<C, R, T, Q> const& y, U a);
32
34 }//namespace glm
35
36 #include "matrix_common.inl"
glm::mix
GLM_FUNC_DECL genTypeT mix(genTypeT x, genTypeT y, genTypeU a)
If genTypeU is a floating scalar or vector: Returns x * (1.0 - a) + y * a, i.e., the linear blend of ...
glm
Definition: common.hpp:20